/*
 * Recorder.c
 *
 *  Created on: Jul 25, 2012
 *      Author: a0866685
 */

#include "Recorder.h"
#include "Haptics.h"
#include "Actuator_Waveforms.h"


extern struct Element* modePtr;
extern struct Element* buttonPtr;
extern const struct Element* buttonList[];


static uint8_t  	IsRecording = 0;
static uint8_t 		IsPlaying = 0;
static uint8_t		IsPressRecording = 0;
static uint16_t 	pressCounter = 0;
static uint16_t 	pauseCounter = 0;
static uint16_t 	recordPattern[100];
static uint8_t		recordPatternCounter = 0;
static uint8_t		playbackPatternCounter = 0;
static uint8_t 		IsWaveformActive = 0;

static const unsigned char RTP_Alert_NoBrake_data[] = {
		0x7F, 0x01
};
static const Waveform RTP_Alert_NoBrake = {MODE_RTP,2,RTP_Alert_NoBrake_data};

/**
 * Recorder_Init - Initialize recorder variables
 */
void Recorder_Init()
{
	uint8_t i = 0;

	IsRecording = 0;

	for(i=0; i < 100; i++)
	{
		recordPattern[i] = 0;
	}
}

/**
 * Recorder_IsRecording - return 0 = is not recording, 1 = is recording
 */
uint8_t Recorder_IsRecording()
{
	return IsRecording;
}

/**
 * Recorder_RecordToggle - toggle button to start/stop recording
 */
void Recorder_RecordToggle()
{
	IsRecording = !IsRecording;

	if(IsRecording)
	{
		recordPatternCounter = 0;
		CapTouch_ButtonLEDsOff();
	}
	else
		P3OUT &= 0xFD;

}

/**
 * Recorder_PlayToggle - toggle button to start/stop play back
 */
void Recorder_PlayToggle()
{
	Recorder_Reset();

	IsPlaying = !IsPlaying;
	IsRecording = 0;

	/*if(IsPlaying)
		P3OUT |= 0x02;
	else
		P3OUT &= 0xFD;
		*/
}

/**
 * Recorder_Record - records press sequence of button B2
 */
void Recorder_Record()
{
	if(IsRecording)
	{
		CapTouch_ButtonLEDsOff();
		P1OUT |= BUTTON1;
		CapTouch_FreezeLEDs();

		if(!buttonPtr)
		{
			if(IsPressRecording)							// if previously recording a press
			{
				recordPattern[recordPatternCounter] = pressCounter;		// Store press counter
				IsPressRecording = 0;									// Stop press recording, begin pause recording
				recordPatternCounter++;									// Increment recordPattern[] pointer
				pauseCounter = 0;										// Reset pause counter
				Haptics_DisableAmplifier();								// Stop Output
			}

			pauseCounter++;									// Count the time during a Pause
		}
		else if(buttonPtr->sequenceNumber == 1)
		{
			if(!IsPressRecording)							// if previously recording a pause
			{
				recordPattern[recordPatternCounter] = pauseCounter;		// Store pause counter
				IsPressRecording = 1;									// Stop pause recording, begin press recording
				recordPatternCounter++;									// Increment recordPattern[] pointer
				pressCounter = 0;										// Reset pause counter

				/* Output Waveform in RTP Mode */
				Haptics_EnableAmplifier();								// Enable the amplifier
				Haptics_SetERMOpenLoopMode(0);							// Set ERM to closed-loop mode
				I2C_WriteSingleByte(DRV260x_MODE,TRIGGER_INTERNAL);		// Set to Internal Trigger temporarily
				Haptics_SetActuator(defaultActuator);					// Set default actuator
				Haptics_HardwareMode(RTP_Alert_NoBrake.inputMode);		// Configure the Hardware (load switch, GPIOs)
				Haptics_SendTriggerType();								// Send trigger type to DRV260x
				Haptics_SendActuatorSettings();							// Send actuator settings to DRV260x
				Haptics_DisableTriggerActive(); 						// Stop waveform playback
				Haptics_OutputWaveform(RTP_Alert_NoBrake);				// Send waveform data to driver

				Haptics_EffectActive(0);								// Trick software to think no effect is playing

			}

			pressCounter++;									// Count the time during a Press
		}
	}
}

/**
 * Recorder_Reset - reset all variables and statuses
 */
void Recorder_Reset()
{
	IsPlaying = 0;
	playbackPatternCounter = 0;
	IsRecording = 0;
	IsWaveformActive = 0;
	pauseCounter = 0;
	pressCounter = 0;
	Haptics_EnableAmplifier();
	Haptics_DisableTriggerActive(); 	// 	Stop Output
	Haptics_DisableAmplifier();
}

/**
 * Recorder_Playback - playback recorded sequence
 */
void Recorder_Playback()
{
	if(IsPlaying)
	{
		CapTouch_ButtonLEDsOff();
		P1OUT |= BUTTON3;
		CapTouch_FreezeLEDs();

		if(!IsPressRecording)
		{
			pauseCounter++;

			if(pauseCounter >= recordPattern[playbackPatternCounter])
			{
				pauseCounter = 0;
				playbackPatternCounter++;
				IsPressRecording = 1;
			}
		}
		else
		{
			pressCounter++;

			if(pressCounter >= recordPattern[playbackPatternCounter])
			{
				pressCounter = 0;
				playbackPatternCounter++;
				IsPressRecording = 0;

				// Stop Play back
				Haptics_DisableAmplifier();
				IsWaveformActive = 0;

				CapTouch_UnfreezeLEDs();
				CapTouch_ButtonLEDsOff();

			}
			else if(!IsWaveformActive)
			{
				IsWaveformActive = 1;

				/* Output Waveform in RTP Mode */
				Haptics_EnableAmplifier();								// Enable the amplifier
				I2C_WriteSingleByte(DRV260x_MODE,TRIGGER_INTERNAL);		// Set to Internal Trigger temporarily
				Haptics_SetERMOpenLoopMode(0);							// Set ERM to closed-loop mode
				Haptics_SetActuator(defaultActuator);					// Set default actuator
				Haptics_HardwareMode(RTP_Alert_NoBrake.inputMode);		// Configure the Hardware (load switch, GPIOs)
				Haptics_SendActuatorSettings();							// Send actuator settings to DRV260x
				Haptics_DisableTriggerActive(); 						// Stop waveform playback
				Haptics_OutputWaveform(RTP_Alert_NoBrake);				// Send waveform data to driver

				Haptics_EffectActive(0);								// Trick software to think no effect is playing
			}

		}

		if(playbackPatternCounter >= recordPatternCounter)
		{
			Recorder_Reset();
		}
	}
	else
	{

	}
}
